# Jupyter template

A simple template for jupyter notebooks.

The extension sets up a new Jupyter Notebook 
with a conventional and general-purpose
template to shape Data Science analysis. 
Moreover, adds a cell with commonly used imports, 
and prompts for a notebook name. 
Quite annoyingly.


## References
Please consider reading the following resources for
a more comprehensive understanding:
- Will Kohersen, [Set Your Jupyter Notebook up Right with this Extension](https://towardsdatascience.com/set-your-jupyter-notebook-up-right-with-this-extension-24921838a332)
- Will Kohersen, [How to Write a Jupyter Notebook Extension](https://towardsdatascience.com/how-to-write-a-jupyter-notebook-extension-a63f9578a38c)
- Will Kohersen, [Setup extension](https://github.com/WillKoehrsen/Data-Analysis/tree/master/setup)